@@ -14,6 +14,6 @@
 #include "gupnp-service-introspection.h"
 
 G_GNUC_INTERNAL GUPnPServiceIntrospection *
-gupnp_service_introspection_new (xmlDoc *scpd);
+gupnp_service_introspection_new (xmlDoc *scpd, GError **error);
 
 #endif /* GUPNP_SERVICE_INTROSPECTION_PRIVATE_H */
