@@ -183,7 +183,7 @@ gupnp_service_proxy_action_iter_get_value (GUPnPServiceProxyActionIter *self,
                                                     self->current->name,
                                                     find_argument);
                 if (result == NULL) {
-                        g_print ("No argument %s\n", self->current->name);
+                        g_debug ("No argument %s\n", self->current->name);
                         return FALSE;
                 }
 
@@ -195,14 +195,13 @@ gupnp_service_proxy_action_iter_get_value (GUPnPServiceProxyActionIter *self,
                                 var);
 
                 if (info == NULL) {
-                        g_print ("No state variable for %s\n",
+                        g_debug ("No state variable for %s\n",
                                  self->current->name);
                         return FALSE;
                 }
 
                 g_value_init (value, info->type);
         } else {
-                g_print ("No introspection\n");
                 // We know nothing about the type, so just give out the string and let
                 // the user transform the value
                 g_value_init (value, G_TYPE_STRING);
@@ -212,6 +211,32 @@ gupnp_service_proxy_action_iter_get_value (GUPnPServiceProxyActionIter *self,
         return TRUE;
 }
 
+/**
+ * gupnp_service_proxy_action_iter_get_value_as:
+ * @self: A GUPnP.ServiceProxyActionIter
+ * @type: The type to convert the value to
+ * @value: (out): The value
+ *
+ * Get the value of the current parameter.
+ *
+ * Converts the value to the given type, similar to the other
+ * finish_action functions.
+ *
+ * Returns: %TRUE if the value could be read successfully
+ * Since: 1.6.8
+ */
+
+gboolean
+gupnp_service_proxy_action_iter_get_value_as (GUPnPServiceProxyActionIter *self,
+                                              GType type,
+                                              GValue *value)
+{
+        g_value_init (value, type);
+
+        gvalue_util_set_value_from_xml_node (value, self->current);
+        return TRUE;
+}
+
 struct _ActionArgument {
         char *name;
         GValue value;
@@ -306,13 +331,10 @@ gupnp_service_proxy_action_ref (GUPnPServiceProxyAction *action)
         return g_atomic_rc_box_acquire (action);
 }
 
-static void
-action_dispose (GUPnPServiceProxyAction *action)
+void
+gupnp_service_proxy_action_reset (GUPnPServiceProxyAction *action)
 {
-        if (action->proxy != NULL) {
-                g_object_remove_weak_pointer (G_OBJECT (action->proxy),
-                                              (gpointer *) &(action->proxy));
-        }
+        g_clear_weak_pointer (&action->proxy);
         g_clear_error (&action->error);
         g_clear_object (&action->msg);
 
@@ -320,10 +342,17 @@ action_dispose (GUPnPServiceProxyAction *action)
                 g_string_free (action->msg_str, TRUE);
                 action->msg_str = NULL;
         }
+        g_clear_pointer (&action->response, g_bytes_unref);
+        action->params = NULL;
+        g_clear_pointer (&action->doc, xmlFreeDoc);
+}
+
+static void
+action_dispose (GUPnPServiceProxyAction *action)
+{
+        gupnp_service_proxy_action_reset (action);
         g_hash_table_destroy (action->arg_map);
         g_ptr_array_unref (action->args);
-        g_clear_pointer (&action->response, g_bytes_unref);
-        g_clear_pointer (&action->doc, xmlFreeDoc);
 
         g_free (action->name);
 }
